package aPRENDIZAJE;

import java.awt.Container;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.KeyboardFocusManager;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.UIManager;

public class TabStopTextField extends JTextField {

	
    public TabStopTextField() {
        setFocusTraversalKeysEnabled(false);
        addKeyListener(new KeyAdapter() {
            public void keyTyped(KeyEvent e) {
                if(e.getKeyChar() == '\t') {
                    nextStop(getSelectionEnd(), true);
                }
            }
        });

        addFocusListener(new FocusAdapter() {
            public void focusGained(FocusEvent e) {
                nextStop(0, false);
            }
        });
    }

	public TabStopTextField(int cols){
		TabStopTextField tabStopTextField = new TabStopTextField();
		tabStopTextField.setColumns(cols);
	}
	
    private void nextStop(int pos, boolean changeFocus) {
        boolean next = false;
        int start = getText().indexOf('[', pos);
        int end = 0;
        if(start < 0)
            next = true;
        else {
            end = getText().indexOf(']', start);
            if(end < 0)
                next = true;
        }
        if(next) {
            if(changeFocus)
                KeyboardFocusManager.getCurrentKeyboardFocusManager().focusNextComponent();
        } else {
            setSelectionStart(start);
            setSelectionEnd(end+1);
        }
    }

    public static void main(String[] args) throws Exception {
        System.setProperty("swing.aatext", "true");
        UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        JFrame frame = new JFrame("Ejemplo de TabStopTextField");

        JPanel p = new JPanel();
        p.setLayout(new GridBagLayout());
        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridy = 1;
        constraints.insets = new Insets(5, 5, 5, 5);

        JTextField textField = new JTextField();
        Font f = textField.getFont();
        f = f.deriveFont(18f);
        textField.setFont(f);
        textField.setText("Presiona tabulador varias veces");
        textField.setEditable(false);
        addComponent(constraints, p, "", textField, f);

        createTabStopTextField(constraints, "Conexin Jdbc",
                "jdbc:mysql://[host]/[database]?user=[user]&pass=[password]", f, p);

        createTabStopTextField(constraints, "HTML input",
                "<input type='[type]' value='[value]' id='[id]' />", f, p);

        createTabStopTextField(constraints, "Nombre fichero",
                "/home/[usuario]/[nombre].tar.gz", f, p);

        createTabStopTextField(constraints, "Conexin SVN",
                "https://[usuario]@[dominio]/svnroot/repos/[proyecto]/trunk", f, p);

        frame.getContentPane().add(p);
        frame.pack();
        frame.setLocationRelativeTo(null);
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }

    private static void createTabStopTextField(GridBagConstraints constraints,
            String label, String text, Font f, Container c) {
        TabStopTextField tabStopTextField = new TabStopTextField();
        tabStopTextField.setText(text);
        tabStopTextField.setFont(f);
        addComponent(constraints, c, label, tabStopTextField, f);
    }

    private static void addComponent(GridBagConstraints constraints,
            Container c, String label, JComponent component, Font f) {
        constraints.fill = GridBagConstraints.NONE;
        constraints.anchor = GridBagConstraints.LINE_END;
        constraints.gridx = 1;
        JLabel lbl = new JLabel(label);
        lbl.setFont(f.deriveFont(14f));
        c.add(lbl, constraints);

        constraints.fill = GridBagConstraints.BOTH;
        constraints.gridx = 2;
        c.add(component, constraints);
        constraints.gridy++;
    }
}